@@ -6,11 +6,28 @@ use warnings FATAL => 'all';
 use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
+BEGIN {
+	use Term::ReadLine;
+	$ENV{TERM} = 'dumb' if !exists $ENV{TERM};
+
+	eval { my $term = Term::ReadLine->new('none') };
+	if ($EVAL_ERROR) {
+		local $ENV{PERL_RL} = ' ornaments=0';
+	}
+}
+
+# Patch for Debug::Client ticket #831 (MJGARDNER)
+# Turn off ReadLine ornaments
+##local $ENV{PERL_RL} = ' ornaments=0';
+##$ENV{TERM} = 'dumb' if ! exists $ENV{TERM};
+
+
 if ( $OSNAME eq 'MSWin32' ) {
 	require Win32::Process;
 	require Win32;
 	use constant NORMALPRIORITYCLASS => 0x00000020;
 }
+
 #use Data::Printer { caller_info => 1, colored => 1, };
 use Exporter ();
 use File::Temp qw(tempdir);
@@ -28,12 +45,13 @@ sub start_script {
 	my $path = $dir;
 	my $pid;
 	if ( $OSNAME eq 'MSWin32' ) {
-		$pid = 'fudge'; # as we don't get one from win32
+		$pid  = 'fudge'; # as we don't get one from win32
 		$path = Win32::GetLongPathName($path);
 		local $ENV{PERLDB_OPTS} = "RemotePort=$host:$port";
 
 		sleep 1;
 		system( 1, qq($^X -d $file > "$path/out" 2> "$path/err") );
+
 		#spawns an external process and immediately returns its process designator, without waiting for it to terminate
 
 	} else {
@@ -43,14 +61,14 @@ sub start_script {
 
 		if ( not $pid ) {
 			local $ENV{PERLDB_OPTS} = "RemotePort=$host:$port";
-			
+
 			sleep 1;
 			exec qq($EXECUTABLE_NAME -d $file > "$path/out" 2> "$path/err");
 			exit 0;
 		}
 	}
 
-	return ($dir, $pid);
+	return ( $dir, $pid );
 }
 
 sub start_debugger {
